==> zio-aws-batch_2.13-5.17.162.2-sources.jar: zio/aws/batch/model/UpdateComputeEnvironmentRequest.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateComputeEnvironmentRequest(
    computeEnvironment: String,
    state: Optional[zio.aws.batch.model.CEState] = Optional.Absent,
    unmanagedvCpus: Optional[Integer] = Optional.Absent,
    computeResources: Optional[zio.aws.batch.model.ComputeResourceUpdate] =
      Optional.Absent,
    serviceRole: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest = {
    import UpdateComputeEnvironmentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
      .builder()
      .computeEnvironment(computeEnvironment: java.lang.String)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(unmanagedvCpus.map(value => value: java.lang.Integer))(
        _.unmanagedvCpus
      )
      .optionallyWith(computeResources.map(value => value.buildAwsValue()))(
        _.computeResources
      )
      .optionallyWith(serviceRole.map(value => value: java.lang.String))(
        _.serviceRole
      )
      .build()
  }
  def asReadOnly: zio.aws.batch.model.UpdateComputeEnvironmentRequest.ReadOnly =
    zio.aws.batch.model.UpdateComputeEnvironmentRequest.wrap(buildAwsValue())
}
object UpdateComputeEnvironmentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.UpdateComputeEnvironmentRequest =
      zio.aws.batch.model.UpdateComputeEnvironmentRequest(
        computeEnvironment,
        state.map(value => value),
        unmanagedvCpus.map(value => value),
        computeResources.map(value => value.asEditable),
        serviceRole.map(value => value)
      )
    def computeEnvironment: String
    def state: Optional[zio.aws.batch.model.CEState]
    def unmanagedvCpus: Optional[Integer]
    def computeResources
        : Optional[zio.aws.batch.model.ComputeResourceUpdate.ReadOnly]
    def serviceRole: Optional[String]
    def getComputeEnvironment: ZIO[Any, Nothing, String] =
      ZIO.succeed(computeEnvironment)
    def getState: ZIO[Any, AwsError, zio.aws.batch.model.CEState] =
      AwsError.unwrapOptionField("state", state)
    def getUnmanagedvCpus: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("unmanagedvCpus", unmanagedvCpus)
    def getComputeResources: ZIO[
      Any,
      AwsError,
      zio.aws.batch.model.ComputeResourceUpdate.ReadOnly
    ] = AwsError.unwrapOptionField("computeResources", computeResources)
    def getServiceRole: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("serviceRole", serviceRole)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
  ) extends zio.aws.batch.model.UpdateComputeEnvironmentRequest.ReadOnly {
    override val computeEnvironment: String = impl.computeEnvironment(): String
    override val state: Optional[zio.aws.batch.model.CEState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.batch.model.CEState.wrap(value))
    override val unmanagedvCpus: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.unmanagedvCpus())
      .map(value => value: Integer)
    override val computeResources
        : Optional[zio.aws.batch.model.ComputeResourceUpdate.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.computeResources())
        .map(value => zio.aws.batch.model.ComputeResourceUpdate.wrap(value))
    override val serviceRole: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceRole())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
  ): zio.aws.batch.model.UpdateComputeEnvironmentRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-batch_2.13-5.17.225.1-sources.jar: zio/aws/batch/model/UpdateComputeEnvironmentRequest.scala <==
package zio.aws.batch.model
import zio.aws.batch.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateComputeEnvironmentRequest(
    computeEnvironment: String,
    state: Optional[zio.aws.batch.model.CEState] = Optional.Absent,
    unmanagedvCpus: Optional[Integer] = Optional.Absent,
    computeResources: Optional[zio.aws.batch.model.ComputeResourceUpdate] =
      Optional.Absent,
    serviceRole: Optional[String] = Optional.Absent,
    updatePolicy: Optional[zio.aws.batch.model.UpdatePolicy] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest = {
    import UpdateComputeEnvironmentRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
      .builder()
      .computeEnvironment(computeEnvironment: java.lang.String)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(unmanagedvCpus.map(value => value: java.lang.Integer))(
        _.unmanagedvCpus
      )
      .optionallyWith(computeResources.map(value => value.buildAwsValue()))(
        _.computeResources
      )
      .optionallyWith(serviceRole.map(value => value: java.lang.String))(
        _.serviceRole
      )
      .optionallyWith(updatePolicy.map(value => value.buildAwsValue()))(
        _.updatePolicy
      )
      .build()
  }
  def asReadOnly: zio.aws.batch.model.UpdateComputeEnvironmentRequest.ReadOnly =
    zio.aws.batch.model.UpdateComputeEnvironmentRequest.wrap(buildAwsValue())
}
object UpdateComputeEnvironmentRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.batch.model.UpdateComputeEnvironmentRequest =
      zio.aws.batch.model.UpdateComputeEnvironmentRequest(
        computeEnvironment,
        state.map(value => value),
        unmanagedvCpus.map(value => value),
        computeResources.map(value => value.asEditable),
        serviceRole.map(value => value),
        updatePolicy.map(value => value.asEditable)
      )
    def computeEnvironment: String
    def state: Optional[zio.aws.batch.model.CEState]
    def unmanagedvCpus: Optional[Integer]
    def computeResources
        : Optional[zio.aws.batch.model.ComputeResourceUpdate.ReadOnly]
    def serviceRole: Optional[String]
    def updatePolicy: Optional[zio.aws.batch.model.UpdatePolicy.ReadOnly]
    def getComputeEnvironment: ZIO[Any, Nothing, String] =
      ZIO.succeed(computeEnvironment)
    def getState: ZIO[Any, AwsError, zio.aws.batch.model.CEState] =
      AwsError.unwrapOptionField("state", state)
    def getUnmanagedvCpus: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("unmanagedvCpus", unmanagedvCpus)
    def getComputeResources: ZIO[
      Any,
      AwsError,
      zio.aws.batch.model.ComputeResourceUpdate.ReadOnly
    ] = AwsError.unwrapOptionField("computeResources", computeResources)
    def getServiceRole: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("serviceRole", serviceRole)
    def getUpdatePolicy
        : ZIO[Any, AwsError, zio.aws.batch.model.UpdatePolicy.ReadOnly] =
      AwsError.unwrapOptionField("updatePolicy", updatePolicy)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
  ) extends zio.aws.batch.model.UpdateComputeEnvironmentRequest.ReadOnly {
    override val computeEnvironment: String = impl.computeEnvironment(): String
    override val state: Optional[zio.aws.batch.model.CEState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.batch.model.CEState.wrap(value))
    override val unmanagedvCpus: Optional[Integer] = zio.aws.core.internal
      .optionalFromNullable(impl.unmanagedvCpus())
      .map(value => value: Integer)
    override val computeResources
        : Optional[zio.aws.batch.model.ComputeResourceUpdate.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.computeResources())
        .map(value => zio.aws.batch.model.ComputeResourceUpdate.wrap(value))
    override val serviceRole: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceRole())
      .map(value => value: String)
    override val updatePolicy
        : Optional[zio.aws.batch.model.UpdatePolicy.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.updatePolicy())
        .map(value => zio.aws.batch.model.UpdatePolicy.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.batch.model.UpdateComputeEnvironmentRequest
  ): zio.aws.batch.model.UpdateComputeEnvironmentRequest.ReadOnly = new Wrapper(
    impl
  )
}
